@@ -11,6 +11,12 @@
  *   not to make any modifications and use it as it stands.
  *   
  * $Log: sci.c,v $
+ * Revision 1.9  2004/04/30 18:18:36  schwitrs
+ * SciSet kernel access fixup
+ *
+ * Revision 1.8  2004/04/20 20:42:21  schwitrs
+ * moved all direct asm calls from sci.c and hci.c to direct.c
+ *
  * Revision 1.7  2004/02/28 16:21:05  schwitrs
  * removed unused code
  *
@@ -91,7 +97,7 @@
  * 
  */
 
-static const char rcsid[]="$Id: sci.c,v 1.7 2004/02/28 16:21:05 schwitrs Exp $";
+static const char rcsid[]="$Id: sci.c,v 1.9 2004/04/30 18:18:36 schwitrs Exp $";
 
 #include<stdio.h>
 #include<stdlib.h>
@@ -103,6 +109,7 @@ static const char rcsid[]="$Id: sci.c,v 1.7 2004/02/28 16:21:05 schwitrs Exp $";
 
 #include"sci.h"
 #include "kernelInterface.h"
+#include "direct.h"
 
 
 /*
@@ -111,9 +118,10 @@ static const char rcsid[]="$Id: sci.c,v 1.7 2004/02/28 16:21:05 schwitrs Exp $";
 int 
 SciSupportCheck(int *version)
 {
- unsigned short dx;
- unsigned char ah;
- {
+
+ if ( accessMode==ACCESS_DIRECT )
+   return dSciSupportCheck(version);
+ else {
    SMMRegisters regs;
 
    regs.eax = 0xf0f0;
@@ -126,22 +134,7 @@ SciSupportCheck(int *version)
      return (int) (regs.eax & 0xff00)>>8;
    }
  }
- asm ("pushl %%eax\n\t" \
-      "pushl %%ebx\n\t" \
-      "pushl %%ecx\n\t" \
-      "pushl %%edx\n\t" \
-      "movw $0xf0f0,%%ax\n\t" \
-      "movw $0x0000,%%bx\n\t" \
-      "movw $0x0000,%%cx\n\t" \
-      "inb $0xb2,%%al\n\t" \
-      "popl %%ecx\n\t" \
-      "popl %%ebx\n\t" \
-      "popl %%eax\n" \
-      :"=d" (dx), "=a" (ah) : : "memory" );
-
- *version = (int) dx;
-
- return (int) (ah & 0xff);
+ return SCI_FAILURE;
 } /* SciSupportCheck */
 
 
@@ -150,10 +143,12 @@ SciSupportCheck(int *version)
  *
  *   Note: Set and Get will not work unless an interface has been opened.
  */
-int SciOpenInterface(void)
+int 
+SciOpenInterface()
 {
- unsigned char ah;
- {
+ if ( accessMode==ACCESS_DIRECT )
+   return dSciOpenInterface();
+ else {
    SMMRegisters regs;
    regs.eax = 0xf1f1;
    regs.ebx = 0x0000;
@@ -163,68 +158,42 @@ int SciOpenInterface(void)
      return (int) (regs.eax & 0xff00)>>8;
    }
  }
-
-
- asm ("pushl %%eax\n\t" \
-      "pushl %%ebx\n\t" \
-      "pushl %%ecx\n\t" \
-      "movw $0xf1f1,%%ax\n\t" \
-      "movw $0x0000,%%bx\n\t" \
-      "movw $0x0000,%%cx\n\t" \
-      "inb $0xb2,%%al\n\t" \
-      "movb %%ah,%0\n\t" \
-      "popl %%ecx\n\t" \
-      "popl %%ebx\n\t" \
-      "popl %%eax\n" \
-      :"=m" (ah) : : "memory" );
-
- return (int) ah;
+ return SCI_FAILURE;
 } /* SciOpenInterface */
 
 
 /*
  * Close any open interface to the hardware
  */
-int SciCloseInterface(void)
+int 
+SciCloseInterface()
 {
- unsigned char ah;
-
- {
+ if ( accessMode==ACCESS_DIRECT )
+   return dSciCloseInterface();
+ else {
    SMMRegisters regs;
    regs.eax = 0xf2f2;
    regs.ebx = 0x0000;
    regs.ecx = 0x0000;
-
+   
    if ( smmAccess(&regs) != 1 ) {
      return (int) (regs.eax & 0xff00)>>8;
    }
  }
-
- asm ("pushl %%eax\n\t" \
-      "pushl %%ebx\n\t" \
-      "pushl %%ecx\n\t" \
-      "movw $0xf2f2,%%ax\n\t" \
-      "movw $0x0000,%%bx\n\t" \
-      "movw $0x0000,%%cx\n\t" \
-      "inb $0xb2,%%al\n\t" \
-      "popl %%ecx\n\t" \
-      "popl %%ebx\n\t" \
-      "popl %%eax\n" \
-      :"=a" (ah) : : "memory" );
- 
- return (int) (ah & 0xff);
-}
+ return SCI_FAILURE;
+} /* SciCloseInterface */
 
 
 /*
  * Get the setting of a given mode of the laptop
  */
 
-int SciGet(SMMRegisters *reg)
+int 
+SciGet(SMMRegisters *reg)
 {
- unsigned short ax,bx,cx,dx;
-
- {
+ if ( accessMode==ACCESS_DIRECT ) 
+   return dSciGet(reg);
+ else {
    reg->eax = 0xf3f3;
 
    if ( smmAccess(reg) != 1 ) {
@@ -234,80 +203,25 @@ int SciGet(SMMRegisters *reg)
      return (int) (reg->eax & 0xff00)>>8;
    }
  }
- // note confusing mapping
- //ax = 0;
- bx = reg->ebx;
- cx = reg->ecx;
- dx = reg->edx;
-
- asm ("pushl %%esi\n\t" \
-      "pushl %%edi\n\t" \
-      "movw $0xf3f3,%%ax\n\t" \
-      "inb $0xb2,%%al\n\t" \
-      "popl %%edi\n\t" \
-      "popl %%esi\n" \
-      :"=a" (ax), "=b" (bx), "=c" (cx), "=d" (dx) \
-      :"b" (bx), "c" (cx), "d" (dx) \
-      : "memory" );
-
- reg->esi = (ax & 0xff);
- reg->ebx = bx;
- reg->ecx = cx;
- reg->edx = dx;
-
- return (int) (ax & 0xff00)>>8;
-}
+ return SCI_FAILURE;
+} /* SciGet */
 
 
 
 /*
  * Set the setting of a given mode of the laptop
  */
-int SciSet(SMMRegisters *reg)
+int 
+SciSet(SMMRegisters *reg)
 {
- int eax;
-
- reg->eax = 0xf4f4;
-
- {
-   if ( smmAccess(reg) != 1 ) {
+ if ( accessMode==ACCESS_DIRECT )
+   return dSciSet(reg);
+ else {
+   reg->eax = 0xf4f4;
+   if ( smmAccess(reg) != 1 ) 
      return (int) (reg->eax & 0xff00)>>8;
-   }
  }
-
- asm ("# load the values into the registers\n\t" \
-      "pushl %%eax\n\t" \
-      "pushl %%eax\n\t" \
-      "movl 0(%%eax),%%edx\n\t" \
-      "push %%edx\n\t" \
-      "movl 4(%%eax),%%ebx\n\t" \
-      "movl 8(%%eax),%%ecx\n\t" \
-      "movl 12(%%eax),%%edx\n\t" \
-      "movl 16(%%eax),%%esi\n\t" \
-      "movl 20(%%eax),%%edi\n\t" \
-      "popl %%eax\n\t" \
-      "# call the System Management mode\n\t" \
-      "inb $0xb2,%%al\n\t"
-      "# fill out the memory with the values in the registers\n\t" \
-      "xchgl %%eax,(%%esp)\n\t" \
-      "popl %%eax\n\t" \
-      "xchgl %%eax,(%%esp)\n\t"
-      "movl %%ebx,4(%%eax)\n\t" \
-      "movl %%ecx,8(%%eax)\n\t" \
-      "movl %%edx,12(%%eax)\n\t" \
-      "movl %%esi,16(%%eax)\n\t" \
-      "movl %%edi,20(%%eax)\n\t" \
-      "popl %%edx\n\t" \
-      "movl %%edx,0(%%eax)\n\t" \
-      "# setup the return value to the carry flag\n\t" \
-      "lahf\n\t" \
-      "shrl $8,%%eax\n\t" \
-      "andl $1,%%eax\n" \
-      : "=a" (eax)
-      : "a" (reg)
-      : "%ebx", "%ecx", "%edx", "%esi", "%edi", "memory");
-
- return eax;
+ return SCI_FAILURE;
 } /* SciSet */
 
 
