@@ -11,6 +11,9 @@
  *   not to make any modifications and use it as it stands.
  *
  * $Log: sci.h,v $
+ * Revision 1.7  2004/07/11 17:04:10  schwitrs
+ * new features added by G. L. Gragnani
+ *
  * Revision 1.6  2002/11/24 19:46:25  schwitrs
  * mods for kernle interface
  *
@@ -170,11 +173,16 @@ enum {
 	SCI_COOLING_METHOD  = 0x0122,
 	SCI_STANDBY_TIME    = 0x0125,
 	SCI_HIBERNATION     = 0x012d,
+	SCI_LAN_CONTROLLER  = 0x0130,
+	SCI_SOUND_LOGO      = 0x0138,
+	SCI_STARTUP_LOGO    = 0x013a,
 	SCI_LCD_BACKLIGHT   = 0x0305,
 	SCI_DISPLAY_STRETCH = 0x0308,
 	SCI_PARALLEL_PORT   = 0x0501,
 	SCI_POINTING_DEVICE = 0x0505,
 	SCI_INFRARED_PORT   = 0x0508,
+	SCI_USB_LEGACY_MODE = 0x050c,
+	SCI_USB_FDD_EMULAT  = 0x050d,
 	SCI_PASSWORD_MODE   = 0x0600,
 	SCI_PASSWORD_CHECK  = 0x0601,
 	SCI_PASSWORD        = 0x0602,
@@ -304,6 +312,11 @@ enum {
 	SCI_MAINS   = 0x0004
 };
 
+enum {
+	SCI_PICTURE_LOGO    = 0x0000,
+	SCI_ANIMATION_LOGO  = 0x0001
+};
+
 
 /*
  * SCI error codes
