@@ -20,7 +20,7 @@
  *
  */
 
-static char const rcsid[]="$Id: toshset.cc,v 1.42 2005/10/10 02:59:35 schwitrs Exp $";
+static char const rcsid[]="$Id: toshset.cc,v 1.43 2006-09-17 18:11:06 schwitrs Exp $";
 static char const rcsversion[]="$State: Exp $";
 
 
@@ -1555,6 +1555,12 @@ main(      int   argc,
 	<< "machine id: " << hex << id << "\n\t"
 	<< "Don't expect this program to do anything useful!!\n";
 
+ if (SciSupportCheck(&version)==1) {
+   cerr << argv[0] << ": this computer is not supported" << endl;
+   return 1;
+ }
+
+
  if ( checkToshibaID(id) )
    snprintf(versionString,80,
 	    " machine id: 0x%04x    BIOS version:"
@@ -1568,10 +1574,11 @@ main(      int   argc,
 	  "    SCI version: %d.%d\n", id,
 	  (bios & 0xff00)>>8, bios & 0xff,
 	  (version & 0xff00)>>8, version & 0xff);
-   printf("\nplease email this information to "
-	  "charles@schwieters.org and include the "
-	  "model\nand model number, eg. Libretto 50CT "
-	  " model number PA1249E\n");
+   cout << "\nplease email this information to charles@schwieters.org "
+	<< " and include the following: \n"
+	<< " model\nand model number, eg. Libretto 50CT model number PA1249E\n"
+	<< " the output of cat /proc/acpi/toshiba/version\n"
+	<< " lsmod |grep tosh\n";
  }
 
  /* check to see if a copy of wmTuxTime is already running */
@@ -1964,12 +1971,6 @@ main(      int   argc,
    if ( !args.process(argc,argv) )
      return 1;
 
- if ( !fast )
-   if (SciSupportCheck(&version)==1) {
-     cerr << argv[0] << ": this computer is not supported" << endl;
-     return 1;
-   }
-
  SciCloseInterface();
 
  return 0;
